/****************************************************************************
** Meta object code from reading C++ file 'k3bwritingmodewidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../k3b-26.07.80/src/k3bwritingmodewidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'k3bwritingmodewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3K3b17WritingModeWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto K3b::WritingModeWidget::qt_create_metaobjectdata<qt_meta_tag_ZN3K3b17WritingModeWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "K3b::WritingModeWidget",
        "writingModeChanged",
        "",
        "WritingMode",
        "mode",
        "setWritingMode",
        "m",
        "setSupportedModes",
        "WritingModes",
        "modes",
        "setDevice",
        "K3b::Device::Device*",
        "determineSupportedModesFromMedium",
        "Medium",
        "dev",
        "_k_writingModeChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'writingModeChanged'
        QtMocHelpers::SignalData<void(WritingMode)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setWritingMode'
        QtMocHelpers::SlotData<void(WritingMode)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 6 },
        }}),
        // Slot 'setSupportedModes'
        QtMocHelpers::SlotData<void(WritingModes)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setDevice'
        QtMocHelpers::SlotData<void(K3b::Device::Device *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'determineSupportedModesFromMedium'
        QtMocHelpers::SlotData<void(const Medium &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 6 },
        }}),
        // Slot 'determineSupportedModesFromMedium'
        QtMocHelpers::SlotData<void(K3b::Device::Device *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 14 },
        }}),
        // Slot '_k_writingModeChanged'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WritingModeWidget, qt_meta_tag_ZN3K3b17WritingModeWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject K3b::WritingModeWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<IntMapComboBox::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b17WritingModeWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b17WritingModeWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3K3b17WritingModeWidgetE_t>.metaTypes,
    nullptr
} };

void K3b::WritingModeWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WritingModeWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->writingModeChanged((*reinterpret_cast<std::add_pointer_t<WritingMode>>(_a[1]))); break;
        case 1: _t->setWritingMode((*reinterpret_cast<std::add_pointer_t<WritingMode>>(_a[1]))); break;
        case 2: _t->setSupportedModes((*reinterpret_cast<std::add_pointer_t<WritingModes>>(_a[1]))); break;
        case 3: _t->setDevice((*reinterpret_cast<std::add_pointer_t<K3b::Device::Device*>>(_a[1]))); break;
        case 4: _t->determineSupportedModesFromMedium((*reinterpret_cast<std::add_pointer_t<Medium>>(_a[1]))); break;
        case 5: _t->determineSupportedModesFromMedium((*reinterpret_cast<std::add_pointer_t<K3b::Device::Device*>>(_a[1]))); break;
        case 6: _t->d->_k_writingModeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WritingModeWidget::*)(WritingMode )>(_a, &WritingModeWidget::writingModeChanged, 0))
            return;
    }
}

const QMetaObject *K3b::WritingModeWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *K3b::WritingModeWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b17WritingModeWidgetE_t>.strings))
        return static_cast<void*>(this);
    return IntMapComboBox::qt_metacast(_clname);
}

int K3b::WritingModeWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IntMapComboBox::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void K3b::WritingModeWidget::writingModeChanged(WritingMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
